package com.example.julian.endlessroll.entities.particles;

import android.content.Context;

import com.example.julian.endlessroll.entities.textures.TextureLoader;
import com.example.julian.endlessroll.main.game.Timer;

/**
 * Created by Julian on 02.08.2016.
 */
public class ParticleSystem {

    public static final float TRANSFER_VALUE = 0.002f;
    public final ParticleEffect explosion;
    public final ParticleEffect magnet;
    public final ParticleEffect starCollect;
    private ParticleEffect[] effects;

    private TextureLoader textureLoader;

    public ParticleSystem(Context context) throws Exception {
        this.textureLoader = new TextureLoader(context);
        ParticleReader reader = new ParticleReader(context);
        explosion = reader.read("particleEffects/explosion.pe");
        magnet = reader.read("particleEffects/magnet.pe");
        starCollect = reader.read("particleEffects/collectStar.pe");

        effects = new ParticleEffect[]{explosion, magnet, starCollect};
    }

    public void update(Timer timer) {
        synchronized (effects) {
            for (ParticleEffect effect : effects)
                effect.update(timer);
        }
    }

    public void loadTextures() throws Exception {
        synchronized (effects) {
            for (ParticleEffect effect : effects)
                effect.setTexture(textureLoader.loadTexture("particleEffects/" + effect.getTextureName()));
        }
    }

    public void deleteAllSources() {
        synchronized (effects) {
            for (ParticleEffect effect : effects) {
                effect.deleteSources();
            }
        }
    }

    public synchronized ParticleEffect[] getEffects() {
        return effects;
    }
}
