package com.example.julian.endlessroll.entities.tools;

import com.example.julian.endlessroll.data.Vector;
import com.example.julian.endlessroll.entities.DestroyEffect;
import com.example.julian.endlessroll.entities.Player;
import com.example.julian.endlessroll.entities.collision.geometry.Circle;
import com.example.julian.endlessroll.entities.collision.geometry.Geometry;
import com.example.julian.endlessroll.entities.particles.ParticleSource;
import com.example.julian.endlessroll.entities.particles.ParticleSystem;
import com.example.julian.endlessroll.main.game.Timer;

/**
 * Created by Julian on 11.02.2016.
 */
public class Magnet extends Tool {

    private ParticleSource particleSource;

    public Magnet(Vector position, ParticleSystem particleSystem) {
        super(ToolType.MAGNET, position, .24f, .24f, false, false);
        animation.setRequiredDelta(300);
        animation.setIndexSequence(new int[]{1, 1, 0});
        animation.setLooping(true);
        super.setFloating(true);
        particleSource = new ParticleSource(new Vector(position), particleSystem.magnet);
        particleSource.start();
    }

    @Override
    public void destroy(DestroyEffect destroyEffect) {
        super.destroy(destroyEffect);
        particleSource.kill();
    }

    @Override
    public void onPlayerCollision(Player player) {
        float fromPlayerDistance = player.getPosition().vectorTo(super.getPosition()).length();
        float fromPlayerYDistance = super.getPosition().y - player.getPosition().y;
        float t = Math.min(2f, 1 / fromPlayerDistance);
        float influenz = .00004f * t * t;
        if (fromPlayerYDistance < 0) {
            player.getMovement().y -= influenz;
        } else if (fromPlayerYDistance > 0) {
            player.getMovement().y += influenz;
        }
    }

    @Override
    protected Geometry createCollisionBounds() {
        return new Circle(super.getPosition(), 2);
    }
}
