package com.example.julian.endlessroll.levels.worlds;

import android.support.annotation.DrawableRes;

import com.example.julian.endlessroll.R;
import com.example.julian.endlessroll.entities.textures.Texture;
import com.example.julian.endlessroll.entities.textures.TexturePack;

/**
 * Created by Julian on 14.11.2016.
 */

public enum Theme {

    GRASSLANDS("Grasslands", R.drawable.previews_grass, R.drawable.backgrounds_game_grass, R.drawable.terrain_t_grass, R.drawable.terrain_c_grass, R.drawable.obstacles_grass),
    TESTCAVE("Testcave", R.drawable.previews_grass, R.drawable.backgrounds_game_cave, R.drawable.terrain_t_grass, R.drawable.terrain_c_grass, R.drawable.obstacles_cave),
    ICY_MOUNTAINS("Icy Mountains", R.drawable.previews_grass, R.drawable.backgrounds_game_mountains, R.drawable.terrain_t_grass, R.drawable.terrain_c_grass, R.drawable.obstacles_mountains);

    private String name;
    @DrawableRes
    private int previewId;
    @DrawableRes
    private int backgroundId;
    @DrawableRes
    private int terrainId;
    @DrawableRes
    private int ceilingId;
    @DrawableRes
    private int obstacleId;

    private Texture background;
    private Texture terrain;
    private Texture ceiling;
    private Texture obstacle;

    Theme(String name, @DrawableRes int previewId, @DrawableRes int backgroundId, @DrawableRes int terrainId, @DrawableRes int ceilingId, @DrawableRes int obstacleId) {
        this.name = name;
        this.previewId = previewId;
        this.backgroundId = backgroundId;
        this.terrainId = terrainId;
        this.ceilingId = ceilingId;
        this.obstacleId = obstacleId;
    }

    public static void loadAllSpecificTextures(TexturePack texturePack) {
        for (Theme theme : values())
            theme.loadSpecificTextures(texturePack);
    }

    private void loadSpecificTextures(TexturePack texturePack) {
        background = texturePack.loadTexture(backgroundId);
        terrain = texturePack.loadTexture(terrainId);
        ceiling = texturePack.loadTexture(ceilingId);
        obstacle = texturePack.loadAtlas(obstacleId, 2, 2);
    }

    public String getName() {
        return name;
    }

    public int getPreviewId() {
        return previewId;
    }

    public Texture getBackgroundTexture() {
        return background;
    }

    public Texture getTerrainTexture() {
        return terrain;
    }

    public Texture getCeilingTexture() {
        return ceiling;
    }

    public Texture getObstacleTexture() {
        return obstacle;
    }
}
