package com.example.julian.endlessroll.main;

import android.app.Activity;
import android.content.Context;
import android.content.SharedPreferences;

import com.example.julian.endlessroll.entities.tools.ToolSlotSettings;
import com.example.julian.endlessroll.entities.tools.ToolType;
import com.example.julian.endlessroll.levels.Level;
import com.example.julian.endlessroll.levels.LevelPack;
import com.example.julian.endlessroll.main.game.User;
import com.example.julian.endlessroll.sqlDatabase.MyDatabase;

/**
 * Created by Julian on 25.04.2016.
 */
public class DataStorageHandler {

    private final String PREFERENCES_NAME = "GamePreferences";
    private final String SOUND_ON = "Sound";
    private final String USER_EP = "EP";
    private final String USER_LEVEL = "Level";
    private final String USER_STARS = "Stars";
    private final String USER_ENERGY = "Energy";
    private final String USER_TOOL_1 = "Tool1";
    private final String USER_TOOL_2 = "Tool2";
    private final String USER_TOOL_3 = "Tool3";
    private final String USER_TOOL_4 = "Tool4";
    private final String USER_TOOLS_LOCKED = "ToolsLocked";

    private SharedPreferences preferences;
    private MyDatabase database;

    public DataStorageHandler(Activity activity) {
        preferences = activity.getSharedPreferences(PREFERENCES_NAME, Context.MODE_PRIVATE);
        database = new MyDatabase(activity);
    }

    public boolean readIsSoundOn() {
        return preferences.getBoolean(SOUND_ON, true);
    }

    public void writeSoundOn(boolean soundOn) {
        SharedPreferences.Editor editor = preferences.edit();
        editor.putBoolean(SOUND_ON, soundOn);
        editor.apply();
    }

    public User readUserData(User.LvUpListener lvUpListener) throws Exception {
        int ep = preferences.getInt(USER_EP, 0);
        int level = preferences.getInt(USER_LEVEL, 1);
        int stars = preferences.getInt(USER_STARS, 0);
        int energy = preferences.getInt(USER_ENERGY, 0);
        int toolsLocked = preferences.getInt(USER_TOOLS_LOCKED, 3);
        String tool1 = preferences.getString(USER_TOOL_1, ToolType.RAMP.name());
        String tool2 = preferences.getString(USER_TOOL_2, ToolType.NONE.name());
        String tool3 = preferences.getString(USER_TOOL_3, ToolType.NONE.name());
        String tool4 = preferences.getString(USER_TOOL_4, ToolType.NONE.name());
        ToolSlotSettings toolSlotSettings = new ToolSlotSettings(tool1, tool2, tool3, tool4, toolsLocked);
        return new User(lvUpListener, ep, level, stars, energy, toolSlotSettings);
    }

    public void writeUserData(User user) {
        SharedPreferences.Editor editor = preferences.edit();
        editor.putInt(USER_EP, user.getEp());
        editor.putInt(USER_LEVEL, user.getLevel());
        editor.putInt(USER_STARS, user.getStarCount());
        editor.putInt(USER_ENERGY, user.getEnergyCount());
        editor.putString(USER_TOOL_1, user.getToolSlotSettings().get(0).getToolType().name());
        editor.putString(USER_TOOL_2, user.getToolSlotSettings().get(1).getToolType().name());
        editor.putString(USER_TOOL_3, user.getToolSlotSettings().get(2).getToolType().name());
        editor.putString(USER_TOOL_4, user.getToolSlotSettings().get(3).getToolType().name());
        editor.putInt(USER_TOOLS_LOCKED, user.getToolSlotSettings().getLockedSlotCount());
        editor.apply();
    }

    public void writeLevelProgress(Level level) {
        database.open();
        database.writeLevelProgress(level);
        database.close();
    }

    public void writeLevelPackLocked(LevelPack levelPack) {
        database.open();
        database.writeLevelPackLocked(levelPack);
        database.close();
    }

    public void readLevelPackLocked(LevelPack levelPack) {
        database.open();
        database.readLevelPackLocked(levelPack);
        database.close();
    }

    public void readLevelProgress(LevelPack levelPack) {
        database.open();
        for (Level level : levelPack.getLevels())
            database.readLevelProgress(level);
        database.close();
    }

    public void clearLevelProgess() {
        database.open();
        database.clearLevelProgess();
        database.close();
    }

    public void readBoughtTools() {
        database.open();
        database.readBoughtTools();
        database.close();
    }

    public void writeBoughtTools() {
        database.open();
        database.writeBoughtTools();
        database.close();
    }

}
