package com.example.julian.endlessroll.main.game;

import com.example.julian.endlessroll.entities.tools.ToolSlotSettings;
import com.example.julian.endlessroll.levels.levelup.LevelBounty;
import com.example.julian.endlessroll.levels.levelup.LevelUpBounties;
import com.example.julian.endlessroll.main.GameLog;

/**
 * Created by Julian on 10.07.2016.
 */
public class User {

    public interface LvUpListener {
        public void onLvUp(int level);
    }

    private final int LV_DONE_EP = 25;
    private final int STAR_EP = 4;
    private final int ENERGY_EP = 13;
    //MAX EP IN ONE LEVEL: 50 (25 + 3*4 + 13)

    private LvUpListener lvUpListener;
    private int ep;
    private int level;
    private int starCount;
    private int energyCount;
    private ToolSlotSettings toolSlotSettings;

    private LevelUpBounties levelUpBounties;

    public User(LvUpListener lvUpListener, int ep, int level, int starCount, int energyCount, ToolSlotSettings toolSlotSettings) {
        this.lvUpListener = lvUpListener;
        this.ep = ep;
        this.level = level;
        this.starCount = starCount;
        this.energyCount = energyCount;
        this.toolSlotSettings = toolSlotSettings;

        levelUpBounties = new LevelUpBounties(level);
    }

    public void clearData() {
        ep = 0;
        level = 1;
        starCount = 0;
        energyCount = 0;
        toolSlotSettings.reset();
    }

    public void onStarCollected() {
        increaseStarCount(1, true);
    }

    public void increaseStarCount(int starCount, boolean gainEp) {
        this.starCount += starCount;
        if(gainEp)
        gainEp(STAR_EP * starCount);
    }

    public void onEnergyCollected() {
        increaseEnergyCount(1, true);
    }

    public void increaseEnergyCount(int energyCount, boolean gainEp) {
        this.energyCount += energyCount;
        if(gainEp)
        gainEp(ENERGY_EP * energyCount);
    }

    public void gainLvFinishedEp() {
        gainEp(LV_DONE_EP);
    }

    public void gainEp(int amount) {
        ep += amount;
        if (ep >= 100) {
            ep -= 100;
            levelUp();
        }
    }

    private void levelUp() {
        level++;
        levelUpBounties.loadAllForLevel(level);

        toolSlotSettings.unlockSlotsIfLevelReached(levelUpBounties);
        LevelBounty bounty = levelUpBounties.get(level);
        if (bounty != null) {
            increaseStarCount(bounty.getStarCount(), false);
            increaseEnergyCount(bounty.getEnergyCount(), false);
        }
        lvUpListener.onLvUp(level);
    }

    public int getEp() {
        return ep;
    }

    public int getLevel() {
        return level;
    }

    public int getStarCount() {
        return starCount;
    }

    public int getEnergyCount() {
        return energyCount;
    }

    public ToolSlotSettings getToolSlotSettings() {
        return toolSlotSettings;
    }

    public LevelUpBounties getLevelUpBounties() {
        return levelUpBounties;
    }

    //CHEAT
    public void setLevel(int level) {
        this.level = level;
    }

    public void setStarCount(int starCount) {
        this.starCount = starCount;
    }
}
