package com.example.julian.endlessroll.main.screens;

import android.content.Context;
import android.graphics.Typeface;
import android.view.View;
import android.widget.LinearLayout;
import android.widget.RelativeLayout;
import android.widget.TableRow;

import com.example.julian.endlessroll.R;
import com.example.julian.endlessroll.levels.Level;
import com.example.julian.endlessroll.levels.LevelPack;
import com.example.julian.endlessroll.main.GameActivity;
import com.example.julian.endlessroll.views.LevelButton;
import com.example.julian.endlessroll.views.TopBar;
import com.example.julian.endlessroll.views.TopBarData;

import java.util.HashMap;
import java.util.Map;

/**
 * Created by Julian on 23.04.2016.
 */
public class LevelsScreen extends Screen<LinearLayout> implements View.OnClickListener {

    private LevelPack levelPack;
    private Typeface typeface;
    private GameActivity activity;
    private Map<Integer, LevelButton> levelButtons = new HashMap<>();

    private TopBar topBar;
    private TableRow topRow;
    private TableRow bottomRow;

    public LevelsScreen(TopBarData topBarData) {
        super(ScreenType.LEVELS, topBarData.getGameActivity(), R.layout.levels);
        this.activity = topBarData.getGameActivity();
        this.typeface = topBarData.getTypeface();
        topBar = new TopBar(topBarData, ScreenType.LEVELS, (RelativeLayout) layout.findViewById(R.id.levels_topbar));
        topRow = (TableRow) layout.findViewById(R.id.levels_topRow);
        bottomRow = (TableRow) layout.findViewById(R.id.levels_bottomRow);
    }

    public void createList(LevelPack levelPack) {
        this.levelPack = levelPack;
        topRow.removeAllViews();
        bottomRow.removeAllViews();
        levelButtons.clear();
        int levelCount = levelPack.getLevels().size();
        for (Level level : levelPack.getLevels())
            createButton(activity, level, levelCount);
    }

    private void createButton(Context context, Level level, int levelCount) {
        int levelNumber = level.getId();
        LevelButton button = new LevelButton(context, typeface, this, levelNumber, level.isLocked());
        button.showCollectedCurrency(level.getCollectedStars(), level.isEnergyCollected());
        levelButtons.put(levelNumber, button);
        int halfLevelCount = levelCount / 2;
        if (levelCount % 2 == 1)
            halfLevelCount++;

        if (levelNumber <= halfLevelCount)
            topRow.addView(button);
        else
            bottomRow.addView(button);
    }

    @Override
    public void prepareToBeShown() {
        if (levelPack != null)
            createList(levelPack);
        topBar.update();
    }

    @Override
    public void onBackKeyDown() {
        activity.flipToScreen(ScreenType.WORLDS);
    }

    @Override
    public void onClick(View v) {
        for (int levelNumber : levelButtons.keySet()) {
            LevelButton button = levelButtons.get(levelNumber);
            if (button.equals(v) && !button.isLocked()) {
                Level level = levelPack.getLevel(levelNumber);
                activity.startGame(levelPack, level);
            }
        }
    }
}
