package com.example.julian.endlessroll.views;

import android.graphics.Typeface;
import android.view.View;
import android.view.animation.Animation;
import android.view.animation.AnimationUtils;
import android.widget.Button;
import android.widget.RelativeLayout;
import android.widget.TextView;

import com.example.julian.endlessroll.R;
import com.example.julian.endlessroll.main.game.Game;

/**
 * Created by Julian on 09.07.2016.
 */
public class Message implements View.OnClickListener {

    private RelativeLayout layout;
    private Animation fadeIn;
    private MessageType messageType;

    private Game game;
    private TextView title;
    private Button leftButton;
    private Button exitButton;
    private Button tryAgainButton;

    public Message(Game game, Typeface typeface, RelativeLayout layout) {
        this.game = game;
        this.layout = layout;
        fadeIn = AnimationUtils.loadAnimation(game.getContext(), R.anim.fade_in);
        title = (TextView) layout.findViewById(R.id.message_title);
        title.setTypeface(typeface);
        leftButton = (Button) layout.findViewById(R.id.message_leftbutton);
        leftButton.setOnClickListener(this);
        leftButton.setTypeface(typeface);
        exitButton = (Button) layout.findViewById(R.id.message_exitbutton);
        exitButton.setOnClickListener(this);
        exitButton.setTypeface(typeface);
        tryAgainButton = (Button) layout.findViewById(R.id.message_tryagainbutton);
        tryAgainButton.setOnClickListener(this);
        tryAgainButton.setTypeface(typeface);
    }

    public void setMessageType(MessageType messageType) {
        this.messageType = messageType;
        title.setText(messageType.getMessage());
        title.setTextColor(game.getContext().getResources().getColor(messageType.getColor()));
        leftButton.setText(messageType.getLeftButtonText());
        tryAgainButton.setVisibility(messageType == MessageType.WIN ? View.VISIBLE : View.INVISIBLE);
    }

    public void fadeIn(boolean wasLastLevel) {
        leftButton.setEnabled(!wasLastLevel);
        layout.startAnimation(fadeIn);
    }

    public void setInvisible() {
        layout.clearAnimation();
        layout.setVisibility(View.INVISIBLE);
    }

    @Override
    public void onClick(View v) {
        if (v.equals(leftButton)) {
            setInvisible();
            if (messageType.equals(MessageType.GAME_OVER)) {
                game.restartLevel();
            } else {
                game.startNextLevel();
            }
        } else if (v.equals(tryAgainButton)) {
            setInvisible();
            game.restartLevel();
        } else if (v.equals(exitButton)) {
            setInvisible();
            game.toLevelsScreen();
        }
    }
}
