package com.example.julian.endlessroll.views;

import android.content.Context;
import android.graphics.Typeface;
import android.graphics.drawable.Drawable;
import android.graphics.drawable.GradientDrawable;
import android.view.LayoutInflater;
import android.view.View;
import android.widget.FrameLayout;
import android.widget.ImageView;
import android.widget.LinearLayout;
import android.widget.TextView;

import com.example.julian.endlessroll.R;
import com.example.julian.endlessroll.entities.tools.ToolType;
import com.example.julian.endlessroll.main.screens.ToolShopScreen;

/**
 * Created by Julian on 16.07.2016.
 */
public class ToolOfferSlot implements View.OnClickListener {

    private ToolShopScreen toolShopScreen;
    private Context context;
    private ToolType toolType;
    private boolean locked;
    private boolean bought;
    private boolean selected;

    private int colorDisabled;
    private int colorEnabled;
    private int colorEnabledSelected;

    private LinearLayout layout;
    private TextView title;
    private ImageView image;

    public ToolOfferSlot(ToolShopScreen toolShopScreen, Context context, Typeface typeface, ToolType toolType) {
        this.toolShopScreen = toolShopScreen;
        this.context = context;
        this.toolType = toolType;
        bought = toolType.isBought();
        LayoutInflater inflater = LayoutInflater.from(context);
        layout = (LinearLayout) inflater.inflate(R.layout.tool_offer_slot, null);
        layout.setOnClickListener(this);
        FrameLayout slotLayout = (FrameLayout) layout.findViewById(R.id.toolofferslot_slot);
        title = (TextView) layout.findViewById(R.id.toolofferslot_title);
        title.setTypeface(typeface);
        image = (ImageView) slotLayout.findViewById(R.id.toolslot_image);
        image.setBackgroundDrawable(createColoredBackground());
        setLocked(false);

        colorDisabled = context.getResources().getColor(R.color.toolslotDisabled);
        colorEnabled = context.getResources().getColor(R.color.toolslotEnabled);
        colorEnabledSelected = context.getResources().getColor(R.color.toolslotEnabledSelected);
    }

    public void setLocked(boolean locked) {
        this.locked = locked;
        if (locked) {
            title.setText("Level up to unlock");
            image.setImageResource(R.drawable.tools_lockedbutton);
        } else {
            title.setText(toolType.getName());
            image.setImageResource(toolType.getButtonDrawable());
        }
    }

    public boolean isBought() {
        return bought;
    }

    public void updateIsBought() {
        bought = toolType.isBought();
        image.setBackgroundDrawable(createColoredBackground());
    }

    public void setSelected(boolean selected) {
        this.selected = selected;
        image.setBackgroundDrawable(createColoredBackground());
    }

    public void buy() {
        this.bought = true;
        toolType.setBought(true);
        toolShopScreen.setSelectedToolOfferSlot(null);
        setColor(R.color.toolslotEnabled);
    }

    private Drawable createColoredBackground() {
        GradientDrawable gd = new GradientDrawable();
        if (bought) {
            if (selected)
                gd.setColor(colorEnabledSelected);
            else
                gd.setColor(colorEnabled);
        } else {
            gd.setColor(colorDisabled);
        }
        gd.setCornerRadius(10);
        return gd;
    }

    private void setColor(int id) {
        GradientDrawable gd = (GradientDrawable) image.getBackground();
        gd.setColor(context.getResources().getColor(id));
    }

    public boolean isLocked() {
        return locked;
    }

    public ToolType getToolType() {
        return toolType;
    }

    public LinearLayout getLayout() {
        return layout;
    }

    public ImageView getImage() {
        return image;
    }

    @Override
    public void onClick(View v) {
        if (!locked && !bought) {
            toolShopScreen.showPriceButton(this);
        } else if (bought) {
            selected = true;
            image.setBackgroundDrawable(createColoredBackground());
            toolShopScreen.setSelectedToolOfferSlot(this);
        }
    }
}
